@@ -1,7 +1,7 @@
 /* bjnp-io.c
  *
  * (c) 2008, 2009 Louis Lagendijk
- * (c) 2015 Markus Heinz
+ * (c) 2015, 2018 Markus Heinz
  *
  * This software is licensed under the terms of the GPL.
  * For details see file COPYING.
@@ -32,7 +32,6 @@
 #endif
 
 /* Local functions */
-static int charTo2byte (char d[], char s[], int len);
 static int set_cmd (struct BJNP_command *cmd, char cmd_code, int my_session_id,
          int payload_len);
 static int udp_command (const struct sockaddr_in *addr, char *command, 
@@ -44,49 +43,15 @@ static int bjnp_send_broadcast (struct in_addr local_addr,
 			struct in_addr broadcast_addr,
                      	struct BJNP_command cmd, int size);
 static int bjnp_discover_printers (struct printer_list *list);
-static int bjnp_send_job_details (struct sockaddr_in *addr, char *user, 
-			char *title);
 static int bjnp_get_address_for_named_printer (const char *device_uri, 
 				struct sockaddr_in *addr);
 
 /* static data */
 
 static int serial = 0;
-static int session_id;
 struct printer_list list[16];
 static int num_printers = 0;
 
-static int
-charTo2byte (char d[], char s[], int len)
-{
-  /*
-   * copy ASCII string to 2 byte unicode string
-   * Returns: number of characters copied
-   */
-
-  int done = 0;
-  int copied = 0;
-  int i;
-
-  for (i = 0; i < len; i++)
-    {
-      d[2 * i] = '\0';
-      if (s[i] == '\0')
-	{
-	  done = 1;
-	}
-      if (done == 0)
-	{
-	  d[2 * i + 1] = s[i];
-	  copied++;
-	}
-      else
-	d[2 * i + 1] = '\0';
-    }
-  return copied;
-}
-
-
 static int
 set_cmd (struct BJNP_command *cmd, char cmd_code, int my_session_id,
 	 int payload_len)
@@ -506,58 +471,6 @@ bjnp_discover_printers (struct printer_list *list)
   return num_printers;
 }
 
-
-static int
-bjnp_send_job_details (struct sockaddr_in *addr, char *user, char *title)
-{
-/* 
- * send details of printjob to printer
- * Returns: addrlist set to address details of used printer
- */
-
-  char cmd_buf[BJNP_CMD_MAX];
-  char resp_buf[BJNP_RESP_MAX];
-  char hostname[256];
-  int resp_len;
-  struct JOB_DETAILS *job;
-  struct BJNP_command *resp;
-
-  /* send job details command */
-
-  set_cmd ((struct BJNP_command *) cmd_buf, CMD_UDP_PRINT_JOB_DET, 0,
-	   sizeof (*job));
-
-  /* create payload */
-
-  gethostname (hostname, 255);
-
-  job = (struct JOB_DETAILS *) (cmd_buf);
-  charTo2byte (job->unknown, "", sizeof (job->unknown));
-  charTo2byte (job->hostname, hostname, sizeof (job->hostname));
-  charTo2byte (job->username, user, sizeof (job->username));
-  charTo2byte (job->jobtitle, title, sizeof (job->jobtitle));
-
-  bjnp_hexdump (LOG_DEBUG2, "Job details", cmd_buf,
-		(sizeof (struct BJNP_command) + sizeof (*job)));
-
-  bjnp_debug (LOG_DEBUG, "Connecting to %s:%d\n",
-	      inet_ntoa (addr->sin_addr), ntohs (list->addr.sin_port));
-  resp_len =
-    udp_command (&list->addr, cmd_buf,
-		 sizeof (struct BJNP_command) +
-		 sizeof (struct JOB_DETAILS), resp_buf, BJNP_RESP_MAX);
-
-  if (resp_len > 0)
-    {
-      bjnp_hexdump (LOG_DEBUG2, "Job details response:", resp_buf, resp_len);
-      resp = (struct BJNP_command *) resp_buf;
-      session_id = ntohs (resp->session_id);
-
-      return OK;
-    }
-  return COULD_NOT_READ_FROM_PRINTER;
-}
-
 static int
 bjnp_get_address_for_named_printer (const char *device_uri, 
 				struct sockaddr_in *addr)
